@@ -9,11 +9,23 @@
 #include <QDir>
 #include <QUrl>
 
+#ifdef Q_OS_WIN
+#include <cstdio>
+#include <windows.h>
+#endif
+
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("mimetreeparser"));
+#ifdef Q_OS_WIN
+    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
+        freopen("CONOUT$", "w", stdout);
+        freopen("CONOUT$", "w", stderr);
+    }
+#endif
+
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("View mbox file"));
     parser.addPositionalArgument(QStringLiteral("file"), i18n("mbox file"));
@@ -24,5 +36,7 @@ int main(int argc, char *argv[])
     const auto file = QUrl::fromUserInput(args.at(args.count() - 1), QDir::currentPath());
     const auto messageViewer = new MimeTreeParser::Widgets::MessageViewerDialog(file.toLocalFile(), nullptr);
 
-    return messageViewer->exec();
+    messageViewer->show();
+    messageViewer->setAttribute(Qt::WA_DeleteOnClose);
+    return app.exec();
 }
